@@ -1,32 +1,28 @@
 // Copyright (c) 2006 Foundation for Research and Technology-Hellas (Greece).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you may redistribute it under
-// the terms of the Q Public License version 1.0.
-// See the file LICENSE.QPL distributed with CGAL.
+// This file is part of CGAL (www.cgal.org).
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.5/Voronoi_diagram_2/include/CGAL/Voronoi_diagram_2/Face.h $
+// $Id: Face.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Voronoi_diagram_2/include/CGAL/Voronoi_diagram_2/Face.h $
-// $Id: Face.h 29163 2006-03-07 23:41:02Z mkaravel $
-// 
 //
 // Author(s)     : Menelaos Karavelas <mkaravel@iacm.forth.gr>
 
 #ifndef CGAL_VORONOI_DIAGRAM_2_FACE_H
 #define CGAL_VORONOI_DIAGRAM_2_FACE_H 1
 
+#include <CGAL/license/Voronoi_diagram_2.h>
+
+
 #include <CGAL/Voronoi_diagram_2/basic.h>
 #include <CGAL/Voronoi_diagram_2/Accessor.h>
 #include <CGAL/Triangulation_utils_2.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
-CGAL_VORONOI_DIAGRAM_2_BEGIN_NAMESPACE
+namespace VoronoiDiagram_2 { namespace Internal {
 
 template<class VDA>
 class Face
@@ -57,7 +53,7 @@ class Face
 
   // CONSTRUCTORS
   //-------------
-  Face(const VDA* vda = NULL) : vda_(vda) {}
+  Face(const VDA* vda = nullptr) : vda_(vda) {}
   Face(const VDA* vda, Delaunay_vertex_handle v) : vda_(vda), v_(v)
   {
     //    CGAL_precondition( !vda_->face_rejector()(v_) );
@@ -84,14 +80,14 @@ class Face
 
     // the edge circulator gives edges that have v_ as their target
     Delaunay_edge_circulator ec = vda_->dual().incident_edges(v_);
-    Delaunay_edge_circulator ec_start = ec;
+    CGAL_assertion_code( Delaunay_edge_circulator ec_start = ec );
 
     // if I want to return also infinite edges replace the test in
     // the while loop by the following test (i.e., should omit the
     // testing for infinity):
     //           vda_->edge_rejector()(vda_->dual(), ec)
     while ( vda_->edge_rejector()(vda_->dual(), ec) ||
-	    vda_->dual().is_infinite(ec) ) {
+            vda_->dual().is_infinite(ec) ) {
       ++ec;
       CGAL_assertion( ec != ec_start );
     }
@@ -106,15 +102,16 @@ class Face
 #endif
 
     return
-      Halfedge_handle( 
-		      Halfedge(vda_, ec->first->neighbor(ec->second), i_mirror)
-		      );
+      Halfedge_handle(
+                      Halfedge(vda_, ec->first->neighbor(ec->second), i_mirror)
+                      );
   }
 
-  Ccb_halfedge_circulator outer_ccb() const {
+  Ccb_halfedge_circulator ccb() const {
     return Ccb_halfedge_circulator( *halfedge() );
   }
 
+  Ccb_halfedge_circulator outer_ccb() const { return ccb(); }
   // PREDICATES
   //-----------
   bool is_unbounded() const {
@@ -130,7 +127,7 @@ class Face
   }
 
   bool is_halfedge_on_ccb(const Halfedge_handle& he) const {
-    Ccb_halfedge_circulator hc_start = outer_ccb();
+    Ccb_halfedge_circulator hc_start = ccb();
     Ccb_halfedge_circulator hc = hc_start;
     do {
       if ( he == *hc ) { return true; }
@@ -146,7 +143,7 @@ class Face
   // VALIDITY TESTING
   //-----------------
   bool is_valid() const {
-    if ( vda_ == NULL ) { return true; }
+    if ( vda_ == nullptr ) { return true; }
 
     if ( vda_->dual().dimension() < 1 ) { return true; }
 
@@ -154,7 +151,7 @@ class Face
 
     valid = valid && !vda_->edge_rejector()(vda_->dual(), halfedge()->dual());
 
-    Ccb_halfedge_circulator hc = outer_ccb();
+    Ccb_halfedge_circulator hc = ccb();
     Ccb_halfedge_circulator hc_start = hc;
     Face_handle f_this(*this);
     do {
@@ -169,8 +166,8 @@ class Face
   // COMPARISON OPERATORS
   //---------------------
   bool operator==(const Self& other) const {
-    if ( vda_ == NULL ) { return other.vda_ == NULL; }
-    if ( other.vda_ == NULL ) { return vda_ == NULL; }
+    if ( vda_ == nullptr ) { return other.vda_ == nullptr; }
+    if ( other.vda_ == nullptr ) { return vda_ == nullptr; }
     return ( vda_ == other.vda_ && v_ == other.v_ );
   }
 
@@ -179,8 +176,8 @@ class Face
   }
 
   bool operator<(const Self& other) const {
-    if ( vda_ == NULL ) { return other.vda_ != NULL; }
-    if ( other.vda_ == NULL ) { return false; }
+    if ( vda_ == nullptr ) { return other.vda_ != nullptr; }
+    if ( other.vda_ == nullptr ) { return false; }
     if ( vda_ != other.vda_ ) { return vda_ < other.vda_; }
     return v_ < other.v_;
   }
@@ -190,9 +187,9 @@ private:
   Delaunay_vertex_handle v_;
 };
 
-CGAL_VORONOI_DIAGRAM_2_END_NAMESPACE
+} } //namespace VoronoiDiagram_2::Internal
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 
 #endif // CGAL_VORONOI_DIAGRAM_2_FACE_H
